@@ -32,7 +32,6 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.24 2006/03/27 23:09:21 abe Exp $";
 #endif
 
 
@@ -299,7 +298,7 @@ process_node(va)
 #endif	/* defined(HAS_AFS) */
 
 			      );
-		Exit(1);
+		Error();
 	    }
 	}
 /*
@@ -319,6 +318,10 @@ process_node(va)
  * Read the gnode.
  */
 	if (!v->v_gnode || readgnode((KA_T)v->v_gnode, &g)) {
+	    if (Selinet) {
+		Lf->sf = SELEXCLF;
+		return;
+	    }
 	    (void) snpf(Namech, Namechl, "vnode at %s has no gnode\n",
 		print_kptr(va, (char *)NULL, 0));
 	    enter_nm(Namech);
@@ -356,6 +359,10 @@ process_node(va)
 	 * Read the special node.
 	 */
 	    if (!g.gn_data || kread((KA_T)g.gn_data, (char *)&sn, sizeof(sn))) {
+		if (Selinet) {
+		    Lf->sf = SELEXCLF;
+		    return;
+		}
 		(void) snpf(Namech, Namechl,
 		    "vnode at %s: can't read specnode (%s)",
 		    print_kptr(va, tbuf, sizeof(tbuf)),
@@ -367,6 +374,10 @@ process_node(va)
 	 * Read the PFS gnode and its inode and vnode.
 	 */
 	    if (sn.sn_pfsgnode) {
+		if (Selinet) {
+		    Lf->sf = SELEXCLF;
+		    return;
+		}
 		if (readgnode((KA_T)sn.sn_pfsgnode, &g)) {
 		    (void) snpf(Namech, Namechl,
 			"vnode at %s: can't read pfsgnode (%s)",
@@ -433,7 +444,10 @@ process_clone_again:
 			    Lf->inp_ty = 1;
 			    if (ClonePtc >= 0
 			    &&  GET_MAJ_DEV(g.gn_rdev) == ClonePtc) {
-
+				if (Selinet) {
+				    Lf->sf = SELEXCLF;
+				    return;
+				}
 			    /*
 			     * If this is a /dev/ptc stream, enter the device
 			     * name and the channel.
@@ -515,6 +529,10 @@ process_clone_again:
 		}
 #endif	/* AIXV>=4140 */
 
+		if (Selinet) {
+		    Lf->sf = SELEXCLF;
+		    return;
+		}
 	    }
 	/*
 	 * If it's a FIFO, read its fifonode.
@@ -861,7 +879,7 @@ process_clone_again:
 #if	defined(HAS_SANFS)
 	case N_SANFS:
 	    if (sans) {
-	    
+
 	    /*
 	     * DEBUG: this code is insufficient.  It can't be completed until
 	     * IBM makes the SANFS header files available in /usr/include.
@@ -1177,8 +1195,10 @@ process_shmt(sa)
 /*
  * Ignore this file if only Internet files are selected.
  */
-	if (Selinet)
+	if (Selinet) {
+	    Lf->sf |= SELEXCLF;
 	    return;
+	}
 /*
  * Set type to " SMT" and put shmtnode structure address in device column.
  */
