@@ -32,7 +32,6 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dproc.c,v 1.16 2004/01/16 05:34:48 abe Exp abe $";
 #endif
 
 #if	defined(HPUXKERNBITS)
@@ -160,6 +159,7 @@ gather_proc_info()
 	};
 	struct ofa *ofap;
 	int ofasz = (int)sizeof(struct ofa);
+	struct ofile_t oft;
 	char *oftp = (char *)&oft;
 	int oftsz = (int)sizeof(struct ofile_t);
 #else	/* HPUXV<1020 || HPUXV>=1100 */
@@ -231,12 +231,12 @@ gather_proc_info()
 		if (kread(v, (char *)&oftsz, sizeof(oftsz))) {
 		    (void) fprintf(stderr, "%s: can't get FD chunk size\n",
 			Pn);
-		    Exit(1);
+		    Error();
 		}
 		if (!oftsz) {
 		    (void) fprintf(stderr, "%s: bad FD chunk size: %d\n",
 			Pn, oftsz);
-		    Exit(1);
+		    Error();
 		}
 	    }
 	    ofasz = (int)(oftsz / SFDCHUNK);
@@ -244,12 +244,12 @@ gather_proc_info()
 		(void) fprintf(stderr,
 		    "%s: FD chunk size (%d) not exact multiple of %d\n",
 		    Pn, oftsz, SFDCHUNK);
-		Exit(1);
+		Error();
 	    }
 	    if (!(oftp = (char *)malloc((MALLOC_S)oftsz))) {
 		(void) fprintf(stderr, "%s: no space for %d FD bytes\n",
 		    Pn, oftsz);
-		Exit(1);
+		Error();
 	    }
 	}
 #endif	/* HPUXV>=1100 */
@@ -521,14 +521,14 @@ get_kernel_access()
 		(void) fprintf(stderr,
 		    "%s: sysconf(_SC_KERNEL_BITS) returns: %s\n",
 		    Pn, strerror(errno));
-		Exit(1);
+		Error();
 	    }
 	    if (rv != (long)HPUXKERNBITS) {
 		(void) fprintf(stderr,
 		    "%s: FATAL: %s was built for a %d bit kernel, but this\n",
 		    Pn, Pn, HPUXKERNBITS);
 		(void) fprintf(stderr, "      is a %ld bit kernel.\n", rv);
-		Exit(1);
+		Error();
 	    }
 	}
 #endif	/* HPUXV>=1030 */
@@ -567,7 +567,7 @@ get_kernel_access()
  * See if the non-KMEM memory file is readable.
  */
 	if (Memory && !is_readable(Memory, 1))
-	    Exit(1);
+	    Error();
 #endif	/* defined(WILLDROPGID) */
 
 /*
@@ -579,7 +579,7 @@ get_kernel_access()
 	    (void) fprintf(stderr, "%s: can't open ", Pn);
 	    safestrprt(Memory ? Memory : KMEM, stderr, 0);
 	    (void) fprintf(stderr, ": %s\n", strerror(errno_save));
-	    Exit(1);
+	    Error();
 	}
 
 #if	defined(WILLDROPGID)
@@ -593,7 +593,7 @@ get_kernel_access()
  * See if the name list file is readable.
  */
 	if (Nmlst && !is_readable(Nmlst, 1))
-	    Exit(1);
+	    Error();
 #endif	/* defined(WILLDROPGID) */
 
 	(void) build_Nl(Drive_Nl);
@@ -609,7 +609,7 @@ get_kernel_access()
 	    if (!(nl = (struct NLIST_TYPE *)malloc(Nll))) {
 		(void) fprintf(stderr,
 		    "%s: no space (%d) for Nl[] copy\n", Pn, Nll);
-		Exit(1);
+		Error();
 	    }
 	    (void) memcpy((void *)nl, (void *)Nl, (size_t)Nll);
 	}
@@ -621,7 +621,7 @@ get_kernel_access()
 	if (NLIST_TYPE(Nmlst ? Nmlst : N_UNIX, Nl) < 0) {
 	    (void) fprintf(stderr, "%s: can't read namelist from: ", Pn);
 	    safestrprt(Nmlst ? Nmlst : N_UNIX, stderr, 1);
-            Exit(1);
+            Error();
 	}
 	if (get_Nl_value("proc", Drive_Nl, &v) < 0 || !v
 	||  kread((KA_T)v, (char *)&Kp, sizeof(Kp))
@@ -629,7 +629,7 @@ get_kernel_access()
 	||  kread((KA_T)v, (char *)&Np, sizeof(Np))
 	||  !Kp || Np < 1) {
 	    (void) fprintf(stderr, "%s: can't read proc table info\n", Pn);
-	    Exit(1);
+	    Error();
 	}
 	if (get_Nl_value("vfops", Drive_Nl, (KA_T *)&Vnfops) < 0)
 	    Vnfops = (KA_T)NULL;
@@ -637,11 +637,11 @@ get_kernel_access()
 #if	HPUXV<800 && defined(hp9000s300)
 	if (get_Nl_value("upmap", Drive_Nl, (unsigned long *)&Usrptmap) < 0) {
 	    (void) fprintf(stderr, "%s: can't get kernel's Usrptmap\n", Pn);
-	    Exit(1);
+	    Error();
 	}
 	if (get_Nl_value("upt", Drive_Nl, (unsigned long *)&usrpt) < 0) {
 	    (void) fprintf(stderr, "%s: can't get kernel's usrpt\n", Pn);
-	    Exit(1);
+	    Error();
 	}
 #endif	/* HPUXV<800 && defined(hp9000s300) */
 
@@ -649,12 +649,12 @@ get_kernel_access()
 	proc = (struct proc *)Kp;
 	if (get_Nl_value("ubase", Drive_Nl, (unsigned long *)&ubase) < 0) {
 	    (void) fprintf(stderr, "%s: can't get kernel's ubase\n", Pn);
-	    Exit(1);
+	    Error();
 	}
 	if (get_Nl_value("npids", Drive_Nl, &v) < 0 || !v
 	||  kread((KA_T)v, (char *)&npids, sizeof(npids))) {
 	    (void) fprintf(stderr, "%s: can't get kernel's npids\n", Pn);
-	    Exit(1);
+	    Error();
 	}
 #endif	/* HPUXV<800 && defined(hp9000s800) */
 
@@ -811,7 +811,7 @@ process_text(vasp)
 		if (!Vp) {
 		    (void) fprintf(stderr,
 			"%s: no more space for text vnode pointers\n", Pn);
-		    Exit(1);
+		    Error();
 		}
 	    }
 	    Vp[i++] = va;
