@@ -31,6 +31,8 @@
 
 #include "lsof.h"
 
+#include <inttypes.h>
+
 
 /*
  * Local definitions
@@ -203,7 +205,7 @@ alloc_cbf(len, cbf, cbfa)
 	if (!*cbf) {
 	    (void) fprintf(stderr,
 		"%s: can't allocate command %d bytes\n", Pn, (int)len);
-	     Error();
+	    Error();
 	}
 	return(len);
 }
@@ -354,7 +356,9 @@ gather_proc_info()
 	 * options work properly.
 	 */
 	    else if (!IgnTasks && (Selflags & SELTASK)) {
-		strncpy(cmdbuf, cmd, sizeof(cmdbuf) - 1);
+		if (cmd) {
+		    strncpy(cmdbuf, cmd, sizeof(cmdbuf) - 1);
+		}
 		cmdbuf[sizeof(cmdbuf) - 1] = '\0';
 		cmd = cmdbuf;
 		(void) make_proc_path(pidpath, n, &taskpath, &taskpathl,
@@ -523,7 +527,7 @@ get_fdinfo(p, msk, fi)
 			   && ((opt_flg = FDINFO_TTY_INDEX)))
 #endif	/* defined(HASPTYEPT) */
 #endif	/* defined(HASEPTOPTS) */
-		       ) {
+		) {
 		int val;
 	    /*
 	     * Process a "tty-index:", "eventfd-id:", "Pid:", or "tfid:" line.
@@ -531,14 +535,14 @@ get_fdinfo(p, msk, fi)
 		ep = (char *)NULL;
 		if ((ul = strtoul(fp[1], &ep, 0)) == ULONG_MAX
 		||  !ep || *ep)
-		     continue;
+		    continue;
 
 		val = (int)ul;
 		if (val < 0) {
 		/*
 		 * Oops! If integer overflow occurred, reset the field.
 		 */
-		     val = -1;
+		    val = -1;
 		}
 
 		rv |= opt_flg;
@@ -568,15 +572,15 @@ get_fdinfo(p, msk, fi)
 			/* There can be more than one tfd: lines.
 			   So even if we found one, we can not exit the loop.
 			   However, we can assume tfd lines are continuous. */
-			opt_flg != FDINFO_TFD
-			&& (rv == msk || (rv & FDINFO_TFD))
-		    )
+		     opt_flg != FDINFO_TFD
+		     && (rv == msk || (rv & FDINFO_TFD))
+						    )
 		    || (
 			/* Too many tfds. */
 			opt_flg == FDINFO_TFD
 			&& rv == msk && fi->tfd_count == EPOLL_MAX_TFDS
-		    ))
-		  break;
+			))
+		    break;
 	    }
 	}
 	fclose(fs);
@@ -837,12 +841,11 @@ nm2id(nm, id, idl)
 #else	/* !defined(__STDC__)	   } { */
 	    if (!isascii(*nm) || !isdigit((unsigned char)*cp))
 #endif	/* defined(__STDC__)	   } */
-
 		{
 		    return(1);
 		}
-		tid = tid * 10 + (int)(*nm - '0');
-		tidl++;
+	    tid = tid * 10 + (int)(*nm - '0');
+	    tidl++;
 	}
 	*id = tid;
 	*idl = tidl;
@@ -941,7 +944,7 @@ process_id(idp, idpl, cmd, uid, pid, ppid, pgid, tid, tcmd)
 	static char *dpath = (char *)NULL;
 	static int dpathl = 0;
 	short efs, enls, enss, lnk, oty, pn, pss, sf;
-	int fd, i, ls, n, ss, sv;
+	int fd, i, ls = 0, n, ss, sv;
 	struct l_fdinfo fi;
 	DIR *fdp;
 	struct dirent *fp;
@@ -1032,7 +1035,7 @@ process_id(idp, idpl, cmd, uid, pid, ppid, pgid, tid, tcmd)
 		    ss = SB_ALL;
 		    if (HasNFS) {
 			if ((sv = statsafely(path, &sb)))
-			sv = statEx(pbuf, &sb, &ss);
+			    sv = statEx(pbuf, &sb, &ss);
 		    } else
 			sv = stat(path, &sb);
 		    if (sv) {
@@ -1293,6 +1296,11 @@ process_id(idp, idpl, cmd, uid, pid, ppid, pgid, tid, tcmd)
 		}
 	    }
 	    if (pn || (efs && lfr && oty)) {
+		/* Clear fi in case oty == 0 */
+		fi.eventfd_id = -1;
+		fi.pid = -1;
+		fi.tfd_count = -1;
+
 		if (oty) {
 		    int fdinfo_mask = FDINFO_BASE;
 		    (void) make_proc_path(ipath, j, &pathi, &pathil,
@@ -1338,7 +1346,7 @@ process_id(idp, idpl, cmd, uid, pid, ppid, pgid, tid, tcmd)
 			    Lf->ffg = (long)fi.flags;
 			    Lf->fsv |= FSV_FG;
 			}
-		     }
+		    }
 # endif	/* !defined(HASNOFSFLAGS) */
 
 		}
@@ -1382,10 +1390,10 @@ process_id(idp, idpl, cmd, uid, pid, ppid, pgid, tid, tcmd)
 			 &&  Lf->rdev_def
 			 &&  is_pty_ptmx(Lf->rdev)
 			 &&  (av & FDINFO_TTY_INDEX)
-		    ) {
-			    enter_ptmxi(fi.tty_index);
-			    Lf->tty_index = fi.tty_index;
-			    Lf->sf |= SELPTYINFO;
+			) {
+			enter_ptmxi(fi.tty_index);
+			Lf->tty_index = fi.tty_index;
+			Lf->sf |= SELPTYINFO;
 		    }
 #endif	/* defined(HASEPTOPTS) && defined(HASPTYEPT) */
 
@@ -1402,7 +1410,7 @@ process_id(idp, idpl, cmd, uid, pid, ppid, pgid, tid, tcmd)
 
 static int
 compare_mntns(pid)
-        int pid;                        /* pid of the target process */
+	int pid;                        /* pid of the target process */
 {
 	char nspath[NS_PATH_LENGTH];
 	struct stat sb_self, sb_target;
@@ -1436,7 +1444,7 @@ process_proc_map(p, s, ss)
 {
 	char buf[MAXPATHLEN + 1], *ep, fmtbuf[32], **fp, nmabuf[MAXPATHLEN + 1];
 	dev_t dev;
-	int ds, efs, en, i, mss, nf, sv;
+	int ds, efs, en, i, mss, sv;
 	int eb = 6;
 	INODETYPE inode;
 	MALLOC_S len;
@@ -1445,8 +1453,8 @@ process_proc_map(p, s, ss)
 	int ns = 0;
 	struct stat sb;
 	struct saved_map {
-	    dev_t dev;
-	    INODETYPE inode;
+		dev_t dev;
+		INODETYPE inode;
 	};
 	static struct saved_map *sm = (struct saved_map *)NULL;
 	efsys_list_t *rep;
@@ -1466,7 +1474,7 @@ process_proc_map(p, s, ss)
 	    diff_mntns = 1;
 
 	while (fgets(buf, sizeof(buf), ms)) {
-	    if ((nf = get_fields(buf, ":", &fp, &eb, 1)) < 7)
+	    if (get_fields(buf, ":", &fp, &eb, 1) < 7)
 		continue;			/* not enough fields */
 	    if (!fp[6] || !*fp[6])
 		continue;			/* no path name */
@@ -1563,10 +1571,10 @@ process_proc_map(p, s, ss)
 		uint64_t start, end;
 		int ret;
 
-		if (sscanf(fp[0], "%lx-%lx", &start, &end) != 2)
+		if (sscanf(fp[0], "%"SCNx64"-%"SCNx64, &start, &end) != 2)
 		    goto stat_directly;
 
-		ret = snprintf(addr, sizeof(addr), "%lx-%lx", start, end);
+		ret = snprintf(addr, sizeof(addr), "%"PRIx64"-%"PRIx64, start, end);
 		if (ret >= sizeof(addr) || ret <= 0)
 		    goto stat_directly;
 
@@ -1577,13 +1585,13 @@ process_proc_map(p, s, ss)
 
 		if (!efs) {
 		    if (HasNFS)
-		        sv = statsafely(path, &sb);
+			sv = statsafely(path, &sb);
 		    else
-		        sv = stat(path, &sb);
-	        }
+			sv = stat(path, &sb);
+		}
 	    }
 	    else {
-stat_directly:
+	      stat_directly:
 		if (!efs) {
 		    if (HasNFS)
 			sv = statsafely(fp[6], &sb);
@@ -1709,7 +1717,7 @@ read_id_stat(p, id, cmd, ppid, pgid)
 					 * type */
 {
 	char buf[MAXPATHLEN], *cp, *cp1, **fp;
-	int ch, cx, es, nf, pc;
+	int ch, cx, es, pc;
 	static char *cbf = (char *)NULL;
 	static MALLOC_S cbfa = 0;
 	FILE *fs;
@@ -1723,7 +1731,7 @@ read_id_stat(p, id, cmd, ppid, pgid)
 	    return(-1);
 	if (!(cp = fgets(buf, sizeof(buf), fs))) {
 
-read_id_stat_exit:
+	  read_id_stat_exit:
 
 	    (void) fclose(fs);
 	    return(-1);
@@ -1745,7 +1753,7 @@ read_id_stat_exit:
  *
  */
 	for (++cp; *cp && (*cp == ' '); cp++)
-		;
+	    ;
 	if (!cp || (*cp != '('))
 	    goto read_id_stat_exit;
 	cp++;
@@ -1797,7 +1805,7 @@ read_id_stat_exit:
 	(void) fclose(fs);
 	if (!cp || !*cp)
 	    return(-1);
-	if ((nf = get_fields(cp, (char *)NULL, &fp, (int *)NULL, 0)) < 3)
+	if (get_fields(cp, (char *)NULL, &fp, (int *)NULL, 0) < 3)
 	    return(-1);
 /*
  * Convert and return parent process (fourth field) and process group (fifth
@@ -1958,8 +1966,8 @@ snp_eventpoll(char *p, int len, int *tfds, int tfd_count)
 	len -= ((tfd_count == EPOLL_MAX_TFDS)
 		? 4 /* "...]" */
 		: 1 /* "]" */
-	       ) + 1 /* for the last \0 */
-	;
+	    ) + 1 /* for the last \0 */
+	    ;
 
 	if (len > 1) {
 	    qsort (tfds, tfd_count, sizeof (tfds[0]), fd_compare);
@@ -1971,9 +1979,9 @@ snp_eventpoll(char *p, int len, int *tfds, int tfd_count)
 		/* If the buffer doesn't have enough space, snp_eventpoll_fds puts
 		 * "..." at the end of the buffer. In that case we don't
 		 have to "..." here. */
-		(wl > 3 && p [11 + wl - 1] == '.')
-		? "]"
-		: ((tfd_count == EPOLL_MAX_TFDS)
+				   (wl > 3 && p [11 + wl - 1] == '.')
+				   ? "]"
+				   : ((tfd_count == EPOLL_MAX_TFDS)
 		   /* File descriptors more than EPOLL_MAX_TFDS are associated to
 		    * the eventpoll fd. */
 		   ? "...]"
