@@ -30,14 +30,13 @@
  */
 
 
-#include "../machine.h"
+#include "machine.h"
 
 #if	defined(HASDCACHE)
 
 # if	!defined(lint)
 static char copyright[] =
 "@(#) Copyright 1997 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dvch.c,v 1.12 2001/02/19 12:12:33 abe Exp $";
 # endif	/* !defined(lint) */
 
 #include "../lsof.h"
@@ -128,14 +127,14 @@ alloc_bdcache()
 				       sizeof(struct l_dev))))
 	{
 	    (void) fprintf(stderr, "%s: no space for block devices\n", Pn);
-	    Exit(1);
+	    Error();
 	}
 	if (!(BSdev = (struct l_dev **)malloc((MALLOC_S)(sizeof(struct l_dev *)
 				       * BNdev))))
 	{
 	    (void) fprintf(stderr, "%s: no space for block device pointers\n",
 		Pn);
-	    Exit(1);
+	    Error();
 	}
 }
 # endif	/* defined(HASBLKDEV) */
@@ -152,14 +151,14 @@ alloc_dcache()
 				      sizeof(struct l_dev))))
 	{
 	    (void) fprintf(stderr, "%s: no space for devices\n", Pn);
-	    Exit(1);
+	    Error();
 	}
 	if (!(Sdev = (struct l_dev **)malloc((MALLOC_S)(sizeof(struct l_dev *)
 				      * Ndev))))
 	{
 	    (void) fprintf(stderr, "%s: no space for device pointers\n",
 		Pn);
-	    Exit(1);
+	    Error();
 	}
 }
 
@@ -422,7 +421,7 @@ dcpath(rw, npw)
 	    /*
 	     * ``%h'' converts to the home directory.
 	     */
-	
+
 	    case 'h':
 		if (!p && !(p = getpwuid(Myuid))) {
 		    if (!Fwarn)
@@ -521,7 +520,7 @@ dcpath(rw, npw)
 				"%s: WARNING: ignoring environment: %s",
 				Pn, HASPERSDCPATH);
 			    safestrprt(cp2, stderr, 1);
-			} 
+			}
 			wpp = 0;
 		    }
 		}
@@ -616,7 +615,7 @@ dcpath(rw, npw)
  * will have been issued to stderr.
  */
 	if (merr)
-	    Exit(1);
+	    Error();
 /*
  * Return the index of the first defined path.  Since DCpath[] is arranged
  * in priority order, searching it beginning to end follows priority.
@@ -761,7 +760,7 @@ close_exit:
 	 */
 	    (void) fprintf(stderr, "%s: internal error: open_dcache=%d\n",
 		Pn, m);
-	    Exit(1);
+	    Error();
 	}
 	return(1);
 }
@@ -866,18 +865,19 @@ read_close:
 		    (long)DevDev);
 	if (!strncmp(buf, cbuf, len) && (buf[len] == '\n')) {
 	    if (!Fwarn) {
-		(void) fprintf(stderr, "%s: WARNING: no /dev device in %s: ",
-		    Pn, DCpath[DCpathX]);
-		safestrprt(buf, stderr, 1);
+		(void) fprintf(stderr,
+		    "%s: WARNING: no /dev device in %s: line ", Pn,
+		    DCpath[DCpathX]);
+		safestrprt(buf, stderr, 1+4+8);
 	    }
 	    goto read_close;
 	}
 	if (strcmp(buf, cbuf)) {
 	    if (!Fwarn) {
 		(void) fprintf(stderr,
-		    "%s: WARNING: bad section count line in %s: ",
+		    "%s: WARNING: bad section count line in %s: line ",
 		    Pn, DCpath[DCpathX]);
-		safestrprt(buf, stderr, 1);
+		safestrprt(buf, stderr, 1+4+8);
 	    }
 	    goto read_close;
 	}
@@ -893,9 +893,9 @@ read_close:
 read_dhdr:
 	    if (!Fwarn) {
 		(void) fprintf(stderr,
-		    "%s: WARNING: bad device section header in %s: ",
+		    "%s: WARNING: bad device section header in %s: line ",
 		    Pn, DCpath[DCpathX]);
-		safestrprt(buf, stderr, 1);
+		safestrprt(buf, stderr, 1+4+8);
 	    }
 	    goto read_close;
 	}
@@ -924,26 +924,27 @@ read_dhdr:
 	    if (!(cp = x2dev(buf, &Devtp[i].rdev)) || *cp != ' ') {
 		if (!Fwarn) {
 		    (void) fprintf(stderr,
-			"%s: device %d: bad device in %s: ",
+			"%s: device %d: bad device in %s: line ",
 			Pn, i + 1, DCpath[DCpathX]);
-		    safestrprt(buf, stderr, 1);
+		    safestrprt(buf, stderr, 1+4+8);
 		}
 		goto read_close;
 	    }
 	/*
 	 * Convert inode number.
 	 */
-	    for (cp++, Devtp[i].inode = 0; *cp != ' '; cp++) {
+	    for (cp++, Devtp[i].inode = (INODETYPE)0; *cp != ' '; cp++) {
 		if (*cp < '0' || *cp > '9') {
 		    if (!Fwarn) {
 			(void) fprintf(stderr,
-			    "%s: WARNING: device %d: bad inode # in %s: ",
+			    "%s: WARNING: device %d: bad inode # in %s: line ",
 			    Pn, i + 1, DCpath[DCpathX]);
-			safestrprt(buf, stderr, 1);
+			safestrprt(buf, stderr, 1+4+8);
 		    }
 		    goto read_close;
 		}
-		Devtp[i].inode = (Devtp[i].inode * 10) + (int)(*cp - '0');
+		Devtp[i].inode = (INODETYPE)((Devtp[i].inode * 10)
+			       + (int)(*cp - '0'));
 	    }
 	/*
 	 * Get path name; allocate space for it; copy it; store the
@@ -953,17 +954,18 @@ read_dhdr:
 	    if ((len = strlen(++cp)) < 2 || *(cp + len - 1) != '\n') {
 		if (!Fwarn) {
 		    (void) fprintf(stderr,
-			"%s: WARNING: device %d: bad path in %s: ",
+			"%s: WARNING: device %d: bad path in %s: line ",
 			Pn, i + 1, DCpath[DCpathX]);
-		    safestrprt(cp, stderr, 1);
+		    safestrprt(buf, stderr, 1+4+8);
 		 }
 		 goto read_close;
 	    }
 	    *(cp + len - 1) = '\0';
 	    if (!(Devtp[i].name = mkstrcpy(cp, (MALLOC_S *)NULL))) {
-		(void) fprintf(stderr, "%s: no space for ", Pn);
-		safestrprt(buf, stderr, 1);
-		Exit(1);
+		(void) fprintf(stderr,
+		    "%s: device %d: no space for path: line ", Pn, i + 1);
+		safestrprt(buf, stderr, 1+4+8);
+		Error();
 	    }
 	    Devtp[i].v = 0;
 	    Sdev[i] = &Devtp[i];
@@ -980,9 +982,9 @@ read_dhdr:
 	if (strncmp(buf, "block device section: ", len) != 0) {
 	    if (!Fwarn) {
 		(void) fprintf(stderr,
-		    "%s: WARNING: bad block device section header in %s: ",
+		    "%s: WARNING: bad block device section header in %s: line ",
 		    Pn, DCpath[DCpathX]);
-		safestrprt(buf, stderr, 1);
+		safestrprt(buf, stderr, 1+4+8);
 	    }
 	    goto read_close;
 	}
@@ -1010,26 +1012,27 @@ read_dhdr:
 		if (!(cp = x2dev(buf, &BDevtp[i].rdev)) || *cp != ' ') {
 		    if (!Fwarn) {
 			(void) fprintf(stderr,
-			    "%s: device %d: bad block device in %s: ",
+			    "%s: block dev %d: bad device in %s: line ",
 			    Pn, i + 1, DCpath[DCpathX]);
-			safestrprt(buf, stderr, 1);
+			safestrprt(buf, stderr, 1+4+8);
 		    }
 		    goto read_close;
 		}
 	    /*
 	     * Convert inode number.
 	     */
-		for (cp++, BDevtp[i].inode = 0; *cp != ' '; cp++) {
+		for (cp++, BDevtp[i].inode = (INODETYPE)0; *cp != ' '; cp++) {
 		    if (*cp < '0' || *cp > '9') {
 		      if (!Fwarn) {
 			(void) fprintf(stderr,
-			  "%s: WARNING: block device %d: bad inode # in %s: ",
+			  "%s: WARNING: block dev %d: bad inode # in %s: line ",
 			  Pn, i + 1, DCpath[DCpathX]);
-			safestrprt(buf, stderr, 1);
+			safestrprt(buf, stderr, 1+4+8);
 		      }
 		      goto read_close;
 		    }
-		    BDevtp[i].inode = (BDevtp[i].inode * 10) + (int)(*cp - '0');
+		    BDevtp[i].inode = (INODETYPE)((BDevtp[i].inode * 10)
+				    + (int)(*cp - '0'));
 		}
 	    /*
 	     * Get path name; allocate space for it; copy it; store the
@@ -1039,17 +1042,18 @@ read_dhdr:
 		if ((len = strlen(++cp)) < 2 || *(cp + len - 1) != '\n') {
 		    if (!Fwarn) {
 			(void) fprintf(stderr,
-			    "%s: WARNING: block device %d: bad path in %s: ",
+			    "%s: WARNING: block dev %d: bad path in %s: line",
 			    Pn, i + 1, DCpath[DCpathX]);
-			safestrprt(buf, stderr, 1);
+			safestrprt(buf, stderr, 1+4+8);
 		    }
 		    goto read_close;
 		}
 	        *(cp + len - 1) = '\0';
 		if (!(BDevtp[i].name = mkstrcpy(cp, (MALLOC_S *)NULL))) {
-		    (void) fprintf(stderr, "%s: no space for ", Pn);
-		    safestrprt(cp, stderr, 1);
-		    Exit(1);
+		    (void) fprintf(stderr,
+			"%s: block dev %d: no space for path: line", Pn, i + 1);
+		    safestrprt(buf, stderr, 1+4+8);
+		    Error();
 		}
 	        BDevtp[i].v = 0;
 	        BSdev[i] = &BDevtp[i];
@@ -1080,18 +1084,18 @@ read_dhdr:
 	if (!fgets(buf, sizeof(buf), DCfs) || strcmp(buf, cbuf) != 0) {
 	    if (!Fwarn) {
 		(void) fprintf(stderr,
-		    "%s: WARNING: bad CRC section in %s: ",
+		    "%s: WARNING: bad CRC section in %s: line ",
 		    Pn, DCpath[DCpathX]);
-		safestrprt(buf, stderr, 1);
+		safestrprt(buf, stderr, 1+4+8);
 	    }
 	    goto read_close;
 	}
 	if (fgets(buf, sizeof(buf), DCfs)) {
 	    if (!Fwarn) {
 		(void) fprintf(stderr,
-		    "%s: WARNING: data follows CRC section in %s: ",
+		    "%s: WARNING: data follows CRC section in %s: line ",
 		    Pn, DCpath[DCpathX]);
-		safestrprt(buf, stderr, 1);
+		safestrprt(buf, stderr, 1+4+8);
 	    }
 	    goto read_close;
 	}
@@ -1149,9 +1153,9 @@ rw_clone_sect(m)
 bad_clone_sect:
 		if (!Fwarn) {
 		    (void) fprintf(stderr,
-			"%s: bad clone section header in %s: ",
+			"%s: bad clone section header in %s: line ",
 			Pn, DCpath[DCpathX]);
-		    safestrprt(buf, stderr, 1);
+		    safestrprt(buf, stderr, 1+4+8);
 		}
 		return(1);
 	    }
@@ -1168,8 +1172,9 @@ bad_clone_sect:
 		if (fgets(buf, sizeof(buf), DCfs) == NULL) {
 		    if (!Fwarn) {
 			(void) fprintf(stderr,
-			    "%s: bad clone line in %s: ", Pn, DCpath[DCpathX]);
-			safestrprt(buf, stderr, 1);
+			    "%s: no %d clone line in %s: line ", Pn, i + 1,
+			    DCpath[DCpathX]);
+			safestrprt(buf, stderr, 1+4+8);
 		    }
 		    return(1);
 		}
@@ -1183,8 +1188,9 @@ bad_clone_sect:
 bad_clone_index:
 			if (!Fwarn) {
 			    (void) fprintf(stderr,
-				"%s: bad cached clone device index: ", Pn);
-			    safestrprt(buf, stderr, 1);
+				"%s: clone %d: bad cached device index: line ",
+				Pn, i + 1);
+			    safestrprt(buf, stderr, 1+4+8);
 			}
 			return(1);
 		    }
@@ -1199,9 +1205,10 @@ bad_clone_index:
 	     */
 		if (!(c = (struct clone *)malloc(sizeof(struct clone)))) {
 		    (void) fprintf(stderr,
-			"%s: no space for cached clone: ", Pn);
-		    safestrprt(buf, stderr, 1);
-		    Exit(1);
+			"%s: clone %d: no space for cached clone: line ", Pn,
+			i + 1);
+		    safestrprt(buf, stderr, 1+4+8);
+		    Error();
 		}
 		c->dx = j;
 		c->next = Clone;
@@ -1248,7 +1255,7 @@ bad_clone_index:
  */
 	(void) fprintf(stderr, "%s: internal rw_clone_sect error: %d\n",
 	    Pn, m);
-	Exit(1);
+	Error();
 	return(1);		/* This useless return(1) keeps some
 				 * compilers happy. */
 }
@@ -1319,7 +1326,7 @@ write_dcache()
 	if (BNdev) {
 	    for (i = 0; i < BNdev; i++) {
 		dp = BSdev[i];
-		(void) snpf(buf, sizeof(buf), "%x %ld %s\n", (int)dp->rdev,
+		(void) snpf(buf, sizeof(buf), "%lx %ld %s\n", (long)dp->rdev,
 		    (long)dp->inode, dp->name);
 		if (wr2DCfd(buf, &DCcksum))
 		    return;
@@ -1401,5 +1408,5 @@ wr2DCfd(b, c)
 	return(0);
 }
 #else	/* !defined(HASDCACHE) */
-static char d1[] = "d"; static char *d2 = d1;
+char dvch_d1[] = "d"; char *dvch_d2 = dvch_d1;
 #endif	/* defined(HASDCACHE) */
