@@ -30,20 +30,37 @@
  */
 
 
-#include "../machine.h"
+#include "machine.h"
 
 #if	defined(USE_LIB_PRINT_TCPTPI)
 
 # if	!defined(lint)
 static char copyright[] =
 "@(#) Copyright 1997 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: ptti.c,v 1.4 2004/07/06 19:15:21 abe Exp $";
 # endif	/* !defined(lint) */
 
 #define	TCPSTATES			/* activate tcpstates[] */
 #include "../lsof.h"
 
 
+/*
+ * build_IPstates() -- build the TCP and UDP state tables
+ *
+ * Note: this module does not support a UDP state table.
+ */
+
+void
+build_IPstates()
+{
+
+/*
+ * Set the TcpNstates global variable.
+ */
+	TcpNstates = TCP_NSTATES;
+	TcpSt = (char **)&tcpstates;
+}
+
+
 /*
  * print_tcptpi() - print TCP/TPI info
  */
@@ -60,10 +77,12 @@ print_tcptpi(nl)
 		(void) printf("%cST=", LSOF_FID_TCPTPI);
 	    else
 		putchar('(');
-	    if ((s = Lf->lts.state.i) < 0 || s >= TCP_NSTATES)
+	    if (!TcpNstates)
+		(void) build_IPstates();
+	    if ((s = Lf->lts.state.i) < 0 || s >= TcpNstates)
 		(void) printf("UNKNOWN_TCP_STATE_%d", s);
 	    else
-		(void) fputs(tcpstates[s], stdout);
+		(void) fputs(TcpSt[s], stdout);
 	    ps++;
 	    if (Ffield)
 		putchar(Terminator);
@@ -107,7 +126,8 @@ print_tcptpi(nl)
 	    int opt;
 
 	    if ((opt = Lf->lts.opt)
-	    ||  Lf->lts.qlens || Lf->lts.qlims || Lf->lts.rbszs || Lf->lts.sbsz
+	    ||  Lf->lts.pqlens || Lf->lts.qlens || Lf->lts.qlims
+	    ||  Lf->lts.rbszs  || Lf->lts.sbsz
 	    ) {
 		char sep = ' ';
 
@@ -331,12 +351,16 @@ print_tcptpi(nl)
 		}
 # endif	/* defined(SO_ORDREL) */
 
+		if (Lf->lts.pqlens) {
+		    (void) printf("%cPQLEN=%u", sep, Lf->lts.pqlen);
+		    sep = ',';
+		}
 		if (Lf->lts.qlens) {
-		    (void) printf("%cQLEN=%d", sep, Lf->lts.qlen);
+		    (void) printf("%cQLEN=%u", sep, Lf->lts.qlen);
 		    sep = ',';
 		}
 		if (Lf->lts.qlims) {
-		    (void) printf("%cQLIM=%lu", sep, Lf->lts.qlim);
+		    (void) printf("%cQLIM=%u", sep, Lf->lts.qlim);
 		    sep = ',';
 		}
 		if (Lf->lts.rbszs) {
@@ -1341,5 +1365,5 @@ print_tcptpi(nl)
 	    putchar('\n');
 }
 #else	/* !defined(USE_LIB_PRINT_TCPTPI) */
-static char d1[] = "d"; static char *d2 = d1;
+char ptti_d1[] = "d"; char *ptti_d2 = ptti_d1;
 #endif	/* defined(USE_LIB_PRINT_TCPTPI) */
