@@ -73,7 +73,7 @@ static char copyright[] =
  * Define major and minor extraction macros that work on 64 bit AIX
  * architectures.
  */
- 
+
 #define	major_S(d)	(ISDEVNO64(d) ? major64(d) : minor(d & ~SDEV_REMOTE))
 #define	minor_S(d)	(ISDEVNO64(d) ? (minor64(d) & ~SDEV_REMOTE) : minor(d))
 #undef	X2DEV_T
@@ -95,10 +95,24 @@ static char copyright[] =
 #define	minor_S(dev)	dv_subunit(dev)
 #define	unit_S(dev)	dv_unit(dev)
 #define	minor_X(dp, em)	dv_subunit(x2dev(dp, em))
-#define	unit_X(dp, em)	dv_unit(x2dev(dp, em))	
+#define	unit_X(dp, em)	dv_unit(x2dev(dp, em))
 #endif	/* defined(LT_DIAL_bsdi) */
 
 
+#if	defined(LT_DIAL_freebsd)
+/*
+ *FreeBSD-specific items
+*/
+
+#undef	XDINDEV
+#define	XDINDEV		16
+# if	defined(LT_DEV64)
+#undef	X2DEV_T
+#define	X2DEV_T		unsigned long long
+# endif	/* defined(LT_DEV64) */
+#endif	/* defined(LT_DIAL_freebsd) */
+
+
 #if	defined(LT_DIAL_osr)
 /*
  * OpenUNIX-specific items
@@ -173,6 +187,14 @@ static char copyright[] =
 #include <sys/mkdev.h>
 #endif	/* defined(LT_DIAL_uw) */
 
+#if	defined(LT_DIAL_linux)
+/*
+ * Linux-specific items
+ */
+
+#include <sys/sysmacros.h>
+#endif	/* defined(LT_DIAL_linux) */
+
 
 /*
  * Global variables
@@ -390,7 +412,7 @@ ConvStatDev(dev, ldev)
 /*
  * Use the pre-defined *_S() macros to do the decomposition.
  */
-    ldev->maj = (unsigned int)major_S(*dev);    
+    ldev->maj = (unsigned int)major_S(*dev);
     ldev->min = (unsigned int)minor_S(*dev);
     ldev->unit = (unsigned int)unit_S(*dev);
     return((char *)NULL);
@@ -658,7 +680,7 @@ GetOpt(ct, opt, rules, em, pn)
      * value belongs to the option, position to the option following the
      * possible value, so that the next call to GetOpt() will find it.
      */
-	if(opt[GOx1][GOx2 + 1] != '\0') {
+	if (opt[GOx1][GOx2 + 1] != '\0') {
 	    GOv = &opt[GOx1++][GOx2];
 	} else if (++GOx1 >= ct)
 	    GOv = (char *)NULL;
